@@ -1,3 +1,4 @@
+import re
 from enum import Enum
 
 
@@ -28,5 +29,16 @@ def list_get(arr, index):
     return arr[index] if index < len(arr) else None
 
 
+def ensure_list(value):
+    return value if isinstance(value, list) else [value]
+
+
 def csv(*args, sep=', '):
     return sep.join(arg for arg in args if arg)
+
+
+CAMEL_CASE_PATTERN = re.compile('(?<!^)(?=[A-Z])')
+
+
+def camel_to_snake_case(name):
+    return CAMEL_CASE_PATTERN.sub('_', name).upper()
