@@ -28,13 +28,14 @@ class Rewriter:
         if create:
             create.args['db'] = db
             create.args['this'] = table
-            create.args['file_format'] = exp.FileFormat(this=file_format)
+            if file_format is not None:
+                create.args['file_format'] = exp.FileFormat(this=file_format)
         else:
             create = exp.Create(
                 this=exp.Table(this=table, db=db),
                 kind='table',
                 expression=self.expression,
-                file_format = exp.FileFormat(this=file_format),
+                file_format=exp.FileFormat(this=file_format) if file_format is not None else None,
             )
 
         return create
